Module object

Module object 

Modules

access
border
border_type
borders
bridge
bridge_type
corner
corner_local
corner_reference
corner_road
crg
lane_validity
marking
markings
material
objects
orientation
outline
outline_fill_type
outlines
parking_space
reference
repeat
road_mark_color
side_type
surface
tunnel
tunnel_type

Structs

Object
Describes common 3D objects that have a reference to a given road. Objects are items that influence a road by expanding, delimiting, and supplementing its course. The most common examples are parking spaces, crosswalks, and traffic barriers. There are two ways to describe the bounding box of objects.