pub struct Controller {
pub control: Vec1<Control>,
pub id: String,
pub name: Option<String>,
pub sequence: Option<u64>,
pub additional_data: AdditionalData,
}Expand description
Controllers provides identical states for one or more dynamic signals. Controllers serve as wrappers for the behaviour of a group of signals. Controllers are used for dynamic speed control on motorways, and to control traffic light switching phases.
Fields
control: Vec1<Control>id: StringUnique ID within database
name: Option<String>Name of the controller. May be chosen freely.
sequence: Option<u64>Sequence number (priority) of this controller with respect to other controllers of same logical level
additional_data: AdditionalDataImplementations