pub struct Junction {
pub connection: Vec1<Connection>,
pub priority: Vec<Priority>,
pub controller: Vec<Controller>,
pub surface: Option<Surface>,
pub id: String,
pub main_road: Option<String>,
pub name: Option<String>,
pub orientation: Option<Orientation>,
pub s_end: Option<Length>,
pub s_start: Option<Length>,
pub type: Option<JunctionType>,
pub additional_data: AdditionalData,
}Fields
connection: Vec1<Connection>priority: Vec<Priority>controller: Vec<Controller>surface: Option<Surface>id: StringUnique ID within database
main_road: Option<String>The main road from which the connecting roads of the virtual junction branch off. This attribute is mandatory for virtual junctions and shall not be specified for other junction types.
name: Option<String>Name of the junction. May be chosen freely.
orientation: Option<Orientation>Defines the relevance of the virtual junction according to the driving direction. This attribute is mandatory for virtual junctions and shall not be specified for other junction types. The enumerator “none” specifies that the virtual junction is valid in both directions.
s_end: Option<Length>End position of the virtual junction in the reference line coordinate system. This attribute is mandatory for virtual junctions and shall not be specified for other junction types.
s_start: Option<Length>Start position of the virtual junction in the reference line coordinate system. This attribute is mandatory for virtual junctions and shall not be specified for other junction types.
type: Option<JunctionType>Type of the junction. Common junctions are of type “default”. This attribute is mandatory for virtual junctions and direct junctions. If the attribute is not specified, the junction type is “default”.
additional_data: AdditionalData